@@ -4,7 +4,7 @@ import json
 import os
 import re 
 
-from waypoint_api.waypoint import WaypointSession
+from waypoint import WaypointSession
 
 
 async def main():
